@@ -8,19 +8,18 @@
 void LocationQueryTest::testLocate()
 {
     qRegisterMetaType<LocationQueryResult>("LocationQueryResult");
-    qRegisterMetaType<std::vector<LocationQueryResult>>(
-        "std::vector<LocationQueryResult>");
+    qRegisterMetaType<std::vector<LocationQueryResult>>("std::vector<LocationQueryResult>");
     finished_spy = new QSignalSpy(d, &LocationQuery::located);
     d->locate();
 
     auto ret = finished_spy->wait(30000);
 
     // if failed to located, abort
-    if (!ret)
+    if (!ret) {
         return;
+    }
 
-    auto location =
-        finished_spy->takeFirst().at(0).value<LocationQueryResult>();
+    auto location = finished_spy->takeFirst().at(0).value<LocationQueryResult>();
     QVERIFY(!location.name().isEmpty());
 }
 
@@ -34,10 +33,7 @@ void LocationQueryTest::testQuery()
     auto ret = finished_spy->wait(30000);
 
     if (ret) {
-        QVERIFY(finished_spy->takeFirst()
-                    .at(0)
-                    .value<std::vector<LocationQueryResult>>()
-                    .size() > 0);
+        QVERIFY(finished_spy->takeFirst().at(0).value<std::vector<LocationQueryResult>>().size() > 0);
     } else {
         QVERIFY(networkError_spy->count() > 0);
     }
